<template>
  <div class="relative">
    <button @click="searchBle">搜索蓝牙</button>
    <button @click="stopFindBle">停止搜索</button>
    <button @click="onClose">断开蓝牙</button>
    <input
      class="uni-input-input"
      v-model="dataValue"
      style="padding-left: 15px; height: 102px"
    />
    <button @click="sendData" style="bottom: 20px">发送数据</button>

    <div>回复：{{ replyData }}</div>
    <svg xmlns="http://www.w3.org/2000/svg" version="1.1">
      <circle
        cx="100"
        cy="50"
        r="40"
        stroke="black"
        stroke-width="2"
        fill="red"
      />
    </svg>
    <div style="margin-top: 30px" :key="index" v-for="(item, index) in devices">
      <button style="width: 400px; color: #0081ff" @click="onConn(item)">
        {{ item.name }}
      </button>
    </div>
  </div>
</template>

<script>
import { getBlueToothTool } from "/libs/bluetoothTool.js";
import { BluetoothRequest } from "@/model/BluetoothRequest.js";
import { Toast } from "vant";

// //#ifdef APP-PLUS
// const bluetooth = window.plus.bluetooth;
// const storage = window.plus.storage;
// //#endif
// 使用 TextDecoder 进行解码

let bluetooth = null;
let bluetoothTool = null;
let storage = null;
const inArray = (arr, key, val) => {
  for (let i = 0; i < arr.length; i++) {
    if (arr[i][key] === val) {
      return i;
    }
  }
  return -1;
};

export default {
  data() {
    return {
      bluetooth: null,
      storage: null,
      devices: [],
      connId: "",
      msg: "",
      dataValue: "",
      replyData: "",
      bluetoothTool: null,
      btRequest: null,
    };
  },
  watch: {
    msg() {
      Toast({
        title: this.msg,
      });
    },
  },
  mounted() {
    let that = this;
    if (window.plus) {
      this.initBluetoothTool();
    } else {
      document.addEventListener("plusready", () => {
        that.initBluetoothTool(that);
      });
    }
  },
  methods: {
    initBluetoothTool: (that) => {
      bluetooth = plus.bluetooth;
      storage = plus.storage;
      bluetoothTool = getBlueToothTool();
      that.btRequest = new BluetoothRequest(bluetoothTool);

      // 蓝牙
      bluetoothTool.overwriteOptions({
        discoveryDeviceCallback: that.onDevice, //查询蓝牙列表回调
        discoveryFinishedCallback: function () {
          //搜索完成回调
          that.msg = "搜索完成";
        },

        connExceptionCallback: function (e) {
          //连接失败回调
          console.log("connExceptionCallback" + e);
          that.msg = "设备连接失败";
        },
      });
    },

    sendData: function () {
      this.btRequest.send(this.dataValue).then((res) => {
        this.replyData = res;
      });
    },
    /**
     * 获取完整的接受信息
     */
    getFullData: function () {},
    getData: function () {},
    destroyed: function () {
      console.log("destroyed----------");
      if (this.connId != "") {
        bluetooth.closeBLEConnection({
          deviceId: this.connId,
          success(res) {
            console.log(res);
          },
        });
      }
    },
    searchBle() {
      var that = this;
      console.log("initBlue");
      // if (uni.getAppAuthorizeSetting().locationAuthorized != "authorized") {
      //   Toast({
      //     title: "请打开定位权限",
      //     icon: "none",
      //   });
      //   let timer = setTimeout(() => {
      //     uni.openAppAuthorizeSetting();
      //   }, 1000);
      // } else {
      //   // 使用openBluetoothAdapter 接口，免去主动申请权限的麻烦
      //   bluetooth.openBluetoothAdapter({
      //     success(res) {
      //       that.devices = [];
      //       console.log("打开 蓝牙模块，开始搜索模式...");
      //       console.log(res);
      //       bluetoothTool.discoveryNewDevice();
      //       // that.onDevice()
      //     },
      //   });
      // }

      bluetooth.openBluetoothAdapter({
        success(res) {
          that.devices = [];
          console.log("打开蓝牙模块，开始搜索模式...");
          console.log(res);
          bluetoothTool.discoveryNewDevice();
          // that.onDevice()
        },
      });
    },
    onDevice(newDevice) {
      console.log("监听寻找到新设备的事件---------------");
      console.log(newDevice);
      if (newDevice.name && newDevice.name != "null") {
        const idx = inArray(this.devices, "id", newDevice.id);
        if (idx === -1) {
          this.devices.push({
            id: newDevice.id,
            name: newDevice.name,
            address: newDevice.address,
          });
        } else {
          this.devices[idx] = {
            id: newDevice.id,
            name: newDevice.name,
            address: newDevice.address,
          };
        }
      }
    },
    stopFindBle() {
      console.log("停止搜寻附近的蓝牙外围设备---------------");
      bluetooth.stopBluetoothDevicesDiscovery({
        success(res) {
          console.log(res);
        },
      });
    },
    onConn(item) {
      console.log(item);
      console.log("连接蓝牙---------------" + item.address);

      bluetoothTool.connDevice(item.address, (result) => {
        if (result) {
          storage.setItem("lastBleAddress", item.address);
        }
        console.log("连接结果：", result);
      });
    },
    // 断开电子秤
    onClose() {
      console.log("关闭蓝牙");
      bluetoothTool.sendData("close[&end&]");
      // bluetoothTool.disConnDevice();
      // this.destroyed();
      console.log(this.msgList);
    },
  },
};
</script>

<style></style>
